@@ -1,9 +1,12 @@
+from protowhat.utils import _debug
+from protowhat.checks.check_files import check_file, has_dir
 from pythonwhat.checks.check_funcs import check_part, check_part_index, check_node
 from pythonwhat.checks.has_funcs import has_equal_part
 from pythonwhat.checks import check_object, check_logic, check_funcs, has_funcs
 from pythonwhat.checks.check_function import check_function
 from pythonwhat.checks.check_has_context import has_context
 
+from inspect import signature, Parameter
 from functools import partial, wraps
 from jinja2 import Template
 
@@ -648,25 +651,6 @@ scts = dict()
 # make has_equal_part wrappers
 
 
-# todo: check @wraps implementation
-
-# def partial_with_state(func, *partial_args, **partial_kwargs):
-#     @wraps(func)
-#     def state_partial(state, *args, **kwargs):
-#         func(state, *partial_args, *args, **{**partial_kwargs, **kwargs})
-#     return state_partial
-
-
-# def right_args_partial(func, *last_args, **partial_kwargs):
-#     kwargs_partial = partial(func, **partial_kwargs)
-#
-#     @wraps(func)
-#     def full_partial(*first_args, **kwargs):
-#         kwargs_partial(*first_args, *last_args, **kwargs)
-#
-#     return full_partial
-
-
 def partial_with_offset(offset=1):
     def bound_partial_with_offset(func, *partial_args, **partial_kwargs):
         kwargs_partial = partial(func, **partial_kwargs)
@@ -676,7 +660,35 @@ def partial_with_offset(offset=1):
             full_args = args[:offset] + partial_args + args[offset:]
             return kwargs_partial(*full_args, **kwargs)
 
+        # set correct signature of returned partial
+        # todo: pass arguments as keywords to partial, instead of this decorator?
+        #  (where args are always the same)
+        func_sig = signature(full_partial)
+        parameter_names = tuple(func_sig.parameters)
+
+        partialed_positional_indices = []
+        for kwarg in partial_kwargs:
+            param = func_sig.parameters[kwarg]
+            if param.default is param.empty:
+                partialed_positional_indices.append(parameter_names.index(kwarg))
+
+        partial_params = list(func_sig.parameters.values())
+        for index in sorted(partialed_positional_indices, reverse=True):
+            # appending isn't needed for functionality, but more similar to partial
+            # and it shows that these arguments can still be updated as kwargs
+            partial_params.append(
+                partial_params[index].replace(
+                    kind=Parameter.KEYWORD_ONLY,
+                    default=partial_kwargs[partial_params[index].name],
+                )
+            )
+            del partial_params[index]
+        del partial_params[offset : offset + len(partial_args)]
+
+        full_partial.__signature__ = func_sig.replace(parameters=partial_params)
+
         return full_partial
+
     return bound_partial_with_offset
 
 
@@ -758,5 +770,8 @@ for k in ["check_object", "is_instance", "check_df", "check_keys"]:
 
 scts["has_context"] = has_context
 scts["check_function"] = check_function
+scts["check_file"] = check_file
+scts["has_dir"] = has_dir
+scts["_debug"] = _debug
 
 locals().update(scts)
